==> apache-ftpserver-1.2.0-src.zip: apache-ftpserver-1.2.0/src/examples/ftpserver-osgi-ftplet-service/src/main/java/org/apache/ftpserver/example/ftpletservice/impl/Activator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver.example.ftpletservice.impl;

import java.util.Dictionary;
import java.util.Hashtable;

import org.apache.ftpserver.example.ftpletservice.MyFtplet;
import org.apache.ftpserver.ftplet.Ftplet;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/*
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public class Activator implements BundleActivator {
    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        Dictionary<String, String> properties = new Hashtable<String, String>();
        properties.put("name", "myftplet");

        context.registerService(Ftplet.class.getName(),
            new MyFtplet(), properties);
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        // do nothing
    }
}

==> apache-ftpserver-1.2.1-src.zip: apache-ftpserver-1.2.1/src/examples/ftpserver-osgi-ftplet-service/src/main/java/org/apache/ftpserver/example/ftpletservice/impl/Activator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver.example.ftpletservice.impl;

import java.util.Dictionary;
import java.util.Hashtable;

import org.apache.ftpserver.example.ftpletservice.MyFtplet;
import org.apache.ftpserver.ftplet.Ftplet;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * The OSGi bundle activator for the FtpLet service
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public class Activator implements BundleActivator {
    /**
     * A default constructor
     */
    public Activator() {
        // Do nothing
    }

    /**
     * {@inheritDoc}
     */
    public void start(BundleContext context) throws Exception {
        Dictionary<String, String> properties = new Hashtable<>();
        properties.put("name", "myftplet");

        context.registerService(Ftplet.class.getName(),
            new MyFtplet(), properties);
    }

    /**
     * {@inheritDoc}
     */
    public void stop(BundleContext context) throws Exception {
        // do nothing
    }
}
